==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WeightedCloseIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { WeightedCloseIndicatorDescription } from "./WeightedCloseIndicatorDescription";
/**
 * @hidden
 */
var WeightedCloseIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicatorDescriptionMetadata, _super);
    function WeightedCloseIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicatorDescriptionMetadata.b = function (a) {
        if (WeightedCloseIndicatorDescriptionMetadata.a == null) {
            WeightedCloseIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WeightedCloseIndicatorDescriptionMetadata.c(WeightedCloseIndicatorDescriptionMetadata.a);
        }
        if (a.g(WeightedCloseIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.c = function (a) {
        ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    WeightedCloseIndicatorDescriptionMetadata.d = function (a) {
        WeightedCloseIndicatorDescriptionMetadata.b(a);
        a.u("WeightedCloseIndicator", function () { return new WeightedCloseIndicatorDescription(); });
        a.t("WeightedCloseIndicator", WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.$t = markType(WeightedCloseIndicatorDescriptionMetadata, 'WeightedCloseIndicatorDescriptionMetadata');
    WeightedCloseIndicatorDescriptionMetadata.a = null;
    return WeightedCloseIndicatorDescriptionMetadata;
}(Base));
export { WeightedCloseIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WeightedCloseIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { WeightedCloseIndicatorDescription } from "./WeightedCloseIndicatorDescription";
/**
 * @hidden
 */
var WeightedCloseIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicatorDescriptionMetadata, _super);
    function WeightedCloseIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicatorDescriptionMetadata.b = function (a) {
        if (WeightedCloseIndicatorDescriptionMetadata.a == null) {
            WeightedCloseIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WeightedCloseIndicatorDescriptionMetadata.c(WeightedCloseIndicatorDescriptionMetadata.a);
        }
        if (a.j(WeightedCloseIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.c = function (a) {
        ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    WeightedCloseIndicatorDescriptionMetadata.d = function (a) {
        WeightedCloseIndicatorDescriptionMetadata.b(a);
        a.aa("WeightedCloseIndicator", function () { return new WeightedCloseIndicatorDescription(); });
        a.z("WeightedCloseIndicator", WeightedCloseIndicatorDescriptionMetadata.a);
    };
    WeightedCloseIndicatorDescriptionMetadata.$t = markType(WeightedCloseIndicatorDescriptionMetadata, 'WeightedCloseIndicatorDescriptionMetadata');
    WeightedCloseIndicatorDescriptionMetadata.a = null;
    return WeightedCloseIndicatorDescriptionMetadata;
}(Base));
export { WeightedCloseIndicatorDescriptionMetadata };
